from django.apps import apps
from django.contrib.staticfiles.urls import staticfiles_urlpatterns
from django.urls import include
from django.contrib import admin
from django.urls import path
from django.views.generic import TemplateView

from apis_acdhch_default_settings.views import Imprint

from apis_core.apis_entities.api_views import GetEntityGeneric

urlpatterns = [
    path("apis/", include("apis_core.urls", namespace="apis")),
    path("api-auth/", include("rest_framework.urls", namespace="rest_framework")),
    path("entity/<int:pk>/", GetEntityGeneric.as_view(), name="GetEntityGenericRoot"),
    path("admin/", admin.site.urls),
]
urlpatterns += staticfiles_urlpatterns()

if apps.is_installed("apis_bibsonomy"):
    urlpatterns.append(
        path("bibsonomy/", include("apis_bibsonomy.urls", namespace="bibsonomy"))
    )

urlpatterns.append(path("", TemplateView.as_view(template_name="base.html")))
urlpatterns.append(path("imprint", Imprint.as_view(), name="imprint"))
urlpatterns += [
    path("", include("apis_acdhch_django_auditlog.urls")),
]



import os

from django_auth_ldap.backend import LDAPBackend


class CustomLDAPBackend(LDAPBackend):
    def authenticate_ldap_user(self, user, *args, **kwargs):
        user_list = os.environ.get("AUTH_LDAP_USER_LIST", "").split(",")
        user_list = list(map(str.strip, user_list))
        if user._username not in user_list:
            return None
        return super().authenticate_ldap_user(user, *args, **kwargs)



import requests
import os
from django.views.generic import TemplateView
from django.views.decorators.cache import cache_page
from django.utils.decorators import method_decorator

from django.conf import settings


@method_decorator(cache_page(60 * 5), name="dispatch")
class Imprint(TemplateView):
    template_name = "imprint.html"

    def get_context_data(self) -> str:
        ctx = super().get_context_data()
        base_url = getattr(
            settings, "ACDH_IMPRINT_URL", "https://imprint.acdh.oeaw.ac.at/"
        )
        redmine_id = getattr(settings, "REDMINE_ID", os.getenv("SERVICE_ID", ""))

        r = requests.get(f"{base_url}{redmine_id}")

        if r and redmine_id:
            ctx["imprint"] = r.text
        else:
            ctx["imprint"] = """
            One of our services is currently not available. Please try it later or write
            an email to acdh@oeaw.ac.at; if you are service provider, make sure that you
            provided ACDH_IMPRINT_URL and REDMINE_ID.
            """
        return ctx
